@@ -8,8 +8,9 @@ import django
 import pytest
 from django.core.management import call_command
 from django.test import SimpleTestCase
-from django.test.utils import captured_stdin
-from django.test.utils import captured_stdout
+from django.test.utils import captured_stdin, captured_stdout
+
+from django_rich.management.commands.shell import Command
 
 
 class ShellCommandTestCase(SimpleTestCase):
@@ -26,9 +27,8 @@ class ShellCommandTestCase(SimpleTestCase):
             console.push('Panel.fit("hi!")\n')
         lines = stdout.getvalue().splitlines()
         if django.VERSION >= (5, 2):
-
             assert lines == [
-                "0 objects imported automatically.",
+                "4 objects imported automatically (use -v 2 for details).",
                 "",
                 "╭─────╮",
                 "│ hi! │",
@@ -40,3 +40,17 @@ class ShellCommandTestCase(SimpleTestCase):
                 "│ hi! │",
                 "╰─────╯",
             ]
+
+    @pytest.mark.skipif(
+        django.VERSION < (5, 2),
+        reason="Django 5.2 added the get_auto_imports() method",
+    )
+    def test_get_auto_imports(self):
+        command = Command()
+        auto_imports = command.get_auto_imports()
+        assert auto_imports[-4:] == [
+            "rich.inspect",
+            "rich.print",
+            "rich.print_json",
+            "rich.pretty.pprint",
+        ]
