@@ -13,8 +13,7 @@ from textwrap import dedent
 import django
 import pytest
 from django.db import connection
-from django.test import SimpleTestCase
-from django.test import TestCase
+from django.test import SimpleTestCase, TestCase
 from django.test.runner import DiscoverRunner
 
 
@@ -589,7 +588,7 @@ class TestRunnerTests(SimpleTestCase):
     @durations_test
     def test_durations_upstream_source(self):
         # RichTestRunner completely replaces _printDurations(), so check the
-        # overriden function for changes that may need copying in.
+        # overridden function for changes that may need copying in.
         source = dedent(
             inspect.getsource(
                 unittest.TextTestRunner._printDurations,  # type: ignore[attr-defined]
@@ -750,36 +749,57 @@ class TestRunnerTests(SimpleTestCase):
     @sub_test_test
     def test_subtest_upstream_source(self):
         # RichTextTestResult completely replaces _addSubTest(), so check the
-        # overriden function for changes that may need copying in.
+        # overridden function for changes that may need copying in.
         source = dedent(
             inspect.getsource(
                 unittest.TextTestResult.addSubTest,
             )
         )
-        expected = dedent(
-            """\
-            def addSubTest(self, test, subtest, err):
-                if err is not None:
-                    if self.showAll:
-                        if issubclass(err[0], subtest.failureException):
-                            self._write_status(subtest, "FAIL")
-                        else:
-                            self._write_status(subtest, "ERROR")
-                    elif self.dots:
-                        if issubclass(err[0], subtest.failureException):
-                            self.stream.write('F')
-                        else:
-                            self.stream.write('E')
-                        self.stream.flush()
-                super(TextTestResult, self).addSubTest(test, subtest, err)
-            """
-        )
+        if sys.version_info >= (3, 14):
+            expected = dedent(
+                """\
+                def addSubTest(self, test, subtest, err):
+                    if err is not None:
+                        t = self._theme
+                        if self.showAll:
+                            if issubclass(err[0], subtest.failureException):
+                                self._write_status(subtest, f"{t.fail}FAIL{t.reset}")
+                            else:
+                                self._write_status(subtest, f"{t.fail}ERROR{t.reset}")
+                        elif self.dots:
+                            if issubclass(err[0], subtest.failureException):
+                                self.stream.write(f"{t.fail}F{t.reset}")
+                            else:
+                                self.stream.write(f"{t.fail}E{t.reset}")
+                            self.stream.flush()
+                    super(TextTestResult, self).addSubTest(test, subtest, err)
+                """
+            )
+        else:
+            expected = dedent(
+                """\
+                def addSubTest(self, test, subtest, err):
+                    if err is not None:
+                        if self.showAll:
+                            if issubclass(err[0], subtest.failureException):
+                                self._write_status(subtest, "FAIL")
+                            else:
+                                self._write_status(subtest, "ERROR")
+                        elif self.dots:
+                            if issubclass(err[0], subtest.failureException):
+                                self.stream.write('F')
+                            else:
+                                self.stream.write('E')
+                            self.stream.flush()
+                    super(TextTestResult, self).addSubTest(test, subtest, err)
+                """
+            )
         assert source == expected
 
     @sub_test_test
     def test_write_status_upstream_source(self):
         # RichTextTestResult completely replaces _write_status(), so check the
-        # overriden function for changes that may need copying in.
+        # overridden function for changes that may need copying in.
         source = dedent(
             inspect.getsource(
                 unittest.TextTestResult._write_status,  # type: ignore[attr-defined]
